.. _trojanzoo.utils.module:

module
=======

.. currentmodule:: trojanzoo.utils.module

.. process
.. --------------------------------------

.. autoclass:: BasicObject
   :members:

.. autoclass:: Process
   :members:

.. autoclass:: ModelProcess
   :members:

.. param
.. --------------------------------------

.. autoclass:: Module
   :members:
   :undoc-members:

.. autoclass:: Param
   :members:
   :undoc-members:
